its_data_gp: GP programme Data

its_data_gpR Documentation

GP programme Data

Description

A dummy data set documenting a two stage level intervention programme of the medical GP practice scenario in the vignette. Report ...

Usage

its_data_gp

Format

## 'its_data_gp' A data frame with 104 rows and 4 columns:

Date

Weekly dates

group_var

Variable to indicate either treatment or control row of interest

Period

Description of intervention phase

score

The outcome metric of the scenario - self-reported wellbeing score"

...


multipleITScontrol documentation built on April 4, 2026, 1:08 a.m.