multipleITScontrol-package: multipleITScontrol: Interrupted Time Series with a Control...

multipleITScontrol-packageR Documentation

multipleITScontrol: Interrupted Time Series with a Control and Multiple Interventions Through a Generalised Least Squares Framework

Description

logo

Functions related to performing interrupted-time series through a generalised least squares (GLS) framework on linear outcomes. Allows for multiple interventions and a control with ARMA (autoregressive and moving-average) correction.

Author(s)

Maintainer: Victor Yu victor.yu@hertfordshire.gov.uk

Other contributors:

  • Emily Dickson [contributor]

See Also

Useful links:


multipleITScontrol documentation built on April 4, 2026, 1:08 a.m.