| its_data_bike_programme | R Documentation |
A dummy data set documenting a two stage level intervention programme of the school scenario in the vignette. Report ...
its_data_bike_programme
## 'its_data_bike_programme' A data frame with 104 rows and 4 columns:
Weekly dates
Variable to indicate either treatment or control row of interest
Description of intervention phase
The outcome metric of the scenario - weekly total maintenance incidents"
...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.