slope_difference
slope_difference.RdAscertains whether there is a statistically significant difference in a slope or level during an intervention period between the pilot group and the control group. The estimated difference is relative to the control group. I.e. a positive coefficient means the slope of the pilot group is higher than the control group.
The result is functionally equivalent to a two sided t-test.
Arguments
- model
model output object from
multipleITScontrol::fit_its_model- intervention
which intervention to test significance in difference. Integer value of 1, 2, or 3.
- return
Logical for returning pretty output in console. TRUE by default
Value
A transformed data frame to be passed to transformed_df in fit_its_model.